@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: optparse-simple
 version: 0.0.3
-id: optparse-simple-0.0.3-be3ce0f531703a193d1ed150a818e98b
-key: optpa_IZDqcMThK510kEXQK11tBD
+id: optparse-simple-0.0.3-d17bf30c57f4a8f3b2e963eacb17a6bd
+key: optpa_F3jcKLnLKENBv2MZUJdLlM
 license: BSD3
 copyright: 2015 FP Complete
 maintainer: chrisdone@fpcomplete.com
@@ -19,10 +19,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/optparse-simple-0.0.3
-hs-libraries: HSoptparse-simple-0.0.3-IZDqcMThK510kEXQK11tBD
+hs-libraries: HSoptparse-simple-0.0.3-F3jcKLnLKENBv2MZUJdLlM
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    either-4.4.1-034f73c037cf6acbd6a0e4686245d294
+    either-4.4.1.1-9b4e1ab30e64d0a7367f7fb822cda30c
     gitrev-1.2.0-e94a60465b66be18f7d5d663af7880a5
     optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
